diff mbox series

[v3,6/8] iio: magnetometer: yas530: Rename functions and registers

Message ID f1a49262b124cbcdf4a258f65fd54ee389de3a29.1655509425.git.jahau@rocketmail.com (mailing list archive)
State Changes Requested
Headers show
Series Add support for magnetometer Yamaha YAS537 | expand

Commit Message

Jakob Hauser June 18, 2022, 12:13 a.m. UTC
This is a preparation for adding YAS537 variant.

Rename functions used only by YAS530 & YAS532 from yas5xx to yas530_532.
Same for the registers.

Cc: Linus Walleij <linus.walleij@linaro.org>
Signed-off-by: Jakob Hauser <jahau@rocketmail.com>
Reviewed-by: Linus Walleij <linus.walleij@linaro.org>
Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
---
 drivers/iio/magnetometer/yamaha-yas530.c | 106 ++++++++++++-----------
 1 file changed, 55 insertions(+), 51 deletions(-)

Comments

Jonathan Cameron June 18, 2022, 3 p.m. UTC | #1
On Sat, 18 Jun 2022 02:13:14 +0200
Jakob Hauser <jahau@rocketmail.com> wrote:

> This is a preparation for adding YAS537 variant.
> 
> Rename functions used only by YAS530 & YAS532 from yas5xx to yas530_532.

We've been bitten in the past by naming choices like this, so please
use yas530 only and rely on comments or code that makes it obvious that
it applies to the yas532 as well.

> Same for the registers.
> 
> Cc: Linus Walleij <linus.walleij@linaro.org>
> Signed-off-by: Jakob Hauser <jahau@rocketmail.com>
> Reviewed-by: Linus Walleij <linus.walleij@linaro.org>
> Reviewed-by: Andy Shevchenko <andy.shevchenko@gmail.com>
> ---
>  drivers/iio/magnetometer/yamaha-yas530.c | 106 ++++++++++++-----------
>  1 file changed, 55 insertions(+), 51 deletions(-)
> 
> diff --git a/drivers/iio/magnetometer/yamaha-yas530.c b/drivers/iio/magnetometer/yamaha-yas530.c
> index c6f5f25793c4..98c8d365fab7 100644
> --- a/drivers/iio/magnetometer/yamaha-yas530.c
> +++ b/drivers/iio/magnetometer/yamaha-yas530.c
> @@ -40,20 +40,22 @@
>  
>  #include <asm/unaligned.h>
>  
> -/* This register map covers YAS530 and YAS532 but differs in YAS 537 and YAS539 */
> +/* Commonly used registers */
>  #define YAS5XX_DEVICE_ID		0x80
> -#define YAS5XX_ACTUATE_INIT_COIL	0x81
> -#define YAS5XX_MEASURE			0x82
> -#define YAS5XX_CONFIG			0x83
> -#define YAS5XX_MEASURE_INTERVAL		0x84
> -#define YAS5XX_OFFSET_X			0x85 /* [-31 .. 31] */
> -#define YAS5XX_OFFSET_Y1		0x86 /* [-31 .. 31] */
> -#define YAS5XX_OFFSET_Y2		0x87 /* [-31 .. 31] */
> -#define YAS5XX_TEST1			0x88
> -#define YAS5XX_TEST2			0x89
> -#define YAS5XX_CAL			0x90
>  #define YAS5XX_MEASURE_DATA		0xB0
>  
> +/* Registers used by YAS530 and YAS532 */
> +#define YAS530_532_ACTUATE_INIT_COIL	0x81
As below, don't start listing parts. Just go with the first one
and a comment to say it applies to other devices.  This approach
doesn't age well as a driver gains more supported parts.

#define YAS530_MEASURE is a better choice.

> +#define YAS530_532_MEASURE		0x82
> +#define YAS530_532_CONFIG		0x83
> +#define YAS530_532_MEASURE_INTERVAL	0x84
> +#define YAS530_532_OFFSET_X		0x85 /* [-31 .. 31] */
> +#define YAS530_532_OFFSET_Y1		0x86 /* [-31 .. 31] */
> +#define YAS530_532_OFFSET_Y2		0x87 /* [-31 .. 31] */
> +#define YAS530_532_TEST1		0x88
> +#define YAS530_532_TEST2		0x89
> +#define YAS530_532_CAL			0x90
> +
>  /* Bits in the YAS5xx config register */
>  #define YAS5XX_CONFIG_INTON		BIT(0) /* Interrupt on? */
>  #define YAS5XX_CONFIG_INTHACT		BIT(1) /* Interrupt active high? */
> @@ -182,7 +184,7 @@ static u16 yas532_extract_axis(u8 *data)
>  }
>  
>  /**
> - * yas5xx_measure() - Make a measure from the hardware
> + * yas530_532_measure() - Make a measure from the hardware
>   * @yas5xx: The device state
>   * @t: the raw temperature measurement
>   * @x: the raw x axis measurement
> @@ -190,7 +192,8 @@ static u16 yas532_extract_axis(u8 *data)
>   * @y2: the y2 axis measurement
>   * @return: 0 on success or error code
>   */
> -static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y2)
> +static int yas530_532_measure(struct yas5xx *yas5xx, u16 *t,

This naming convention often causes us problems long run because
people feel they need to keep listing new devices that look similar.

Generally much better to just pick the first part that uses it and
name the function after that.  So here it would be simply
yas530_measure()

> +			      u16 *x, u16 *y1, u16 *y2)
>  {
>  	unsigned int busy;
>  	u8 data[8];
> @@ -198,7 +201,7 @@ static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y
>  	u16 val;
>  
>  	mutex_lock(&yas5xx->lock);
> -	ret = regmap_write(yas5xx->map, YAS5XX_MEASURE, YAS5XX_MEASURE_START);
> +	ret = regmap_write(yas5xx->map, YAS530_532_MEASURE, YAS5XX_MEASURE_START);
>  	if (ret < 0)
>  		goto out_unlock;
>  
> @@ -264,7 +267,7 @@ static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y
>  	return ret;
>  }
>  
> -static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
> +static s32 yas530_532_linearize(struct yas5xx *yas5xx, u16 val, int axis)
>  {
>  	struct yas5xx_calibration *c = &yas5xx->calibration;
>  	static const s32 yas532ac_coef[] = {
> @@ -306,7 +309,7 @@ static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
>  }
>  
>  /**
> - * yas5xx_get_measure() - Measure a sample of all axis and process
> + * yas530_532_get_measure() - Measure a sample of all axis and process
>   * @yas5xx: The device state
>   * @to: Temperature out
>   * @xo: X axis out
> @@ -314,7 +317,8 @@ static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
>   * @zo: Z axis out
>   * @return: 0 on success or error code
>   */
> -static int yas5xx_get_measure(struct yas5xx *yas5xx, s32 *to, s32 *xo, s32 *yo, s32 *zo)
> +static int yas530_532_get_measure(struct yas5xx *yas5xx, s32 *to,
> +				  s32 *xo, s32 *yo, s32 *zo)
>  {
>  	struct yas5xx_calibration *c = &yas5xx->calibration;
>  	u16 t_ref, t, x, y1, y2;
> @@ -323,14 +327,14 @@ static int yas5xx_get_measure(struct yas5xx *yas5xx, s32 *to, s32 *xo, s32 *yo,
>  	int ret;
>  
>  	/* We first get raw data that needs to be translated to [x,y,z] */
> -	ret = yas5xx_measure(yas5xx, &t, &x, &y1, &y2);
> +	ret = yas530_532_measure(yas5xx, &t, &x, &y1, &y2);
>  	if (ret)
>  		return ret;
>  
>  	/* Do some linearization if available */
> -	sx = yas5xx_linearize(yas5xx, x, 0);
> -	sy1 = yas5xx_linearize(yas5xx, y1, 1);
> -	sy2 = yas5xx_linearize(yas5xx, y2, 2);
> +	sx = yas530_532_linearize(yas5xx, x, 0);
> +	sy1 = yas530_532_linearize(yas5xx, y1, 1);
> +	sy2 = yas530_532_linearize(yas5xx, y2, 2);
>  
>  	/* Set the temperature reference value (unit: counts) */
>  	switch (yas5xx->devid) {
> @@ -602,11 +606,11 @@ static const struct regmap_config yas5xx_regmap_config = {
>  };
>  
>  /**
> - * yas53x_extract_calibration() - extracts the a2-a9 and k calibration
> + * yas530_532_extract_calibration() - extracts the a2-a9 and k calibration
>   * @data: the bitfield to use
>   * @c: the calibration to populate
>   */
> -static void yas53x_extract_calibration(u8 *data, struct yas5xx_calibration *c)
> +static void yas530_532_extract_calibration(u8 *data, struct yas5xx_calibration *c)
>  {
>  	u64 val = get_unaligned_be64(data);
>  
> @@ -644,12 +648,12 @@ static int yas530_get_calibration_data(struct yas5xx *yas5xx)
>  	int ret;
>  
>  	/* Dummy read, first read is ALWAYS wrong */
> -	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
> +	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
>  	if (ret)
>  		return ret;
>  
>  	/* Actual calibration readout */
> -	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
> +	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
>  	if (ret)
>  		return ret;
>  	dev_dbg(yas5xx->dev, "calibration data: %*ph\n", 14, data);
> @@ -661,7 +665,7 @@ static int yas530_get_calibration_data(struct yas5xx *yas5xx)
>  	c->Cx = data[0] * 6 - 768;
>  	c->Cy1 = data[1] * 6 - 768;
>  	c->Cy2 = data[2] * 6 - 768;
> -	yas53x_extract_calibration(&data[3], c);
> +	yas530_532_extract_calibration(&data[3], c);
>  
>  	/*
>  	 * Extract linearization:
> @@ -692,11 +696,11 @@ static int yas532_get_calibration_data(struct yas5xx *yas5xx)
>  	int ret;
>  
>  	/* Dummy read, first read is ALWAYS wrong */
> -	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
> +	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
>  	if (ret)
>  		return ret;
>  	/* Actual calibration readout */
> -	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
> +	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
>  	if (ret)
>  		return ret;
>  	dev_dbg(yas5xx->dev, "calibration data: %*ph\n", 14, data);
> @@ -715,7 +719,7 @@ static int yas532_get_calibration_data(struct yas5xx *yas5xx)
>  	c->Cx = data[0] * 10 - 1280;
>  	c->Cy1 = data[1] * 10 - 1280;
>  	c->Cy2 = data[2] * 10 - 1280;
> -	yas53x_extract_calibration(&data[3], c);
> +	yas530_532_extract_calibration(&data[3], c);
>  	/*
>  	 * Extract linearization:
>  	 * Linearization layout in the 32 bits at byte 10:
> @@ -738,7 +742,7 @@ static int yas532_get_calibration_data(struct yas5xx *yas5xx)
>  	return 0;
>  }
>  
> -static void yas5xx_dump_calibration(struct yas5xx *yas5xx)
> +static void yas530_532_dump_calibration(struct yas5xx *yas5xx)
>  {
>  	struct yas5xx_calibration *c = &yas5xx->calibration;
>  
> @@ -761,20 +765,20 @@ static void yas5xx_dump_calibration(struct yas5xx *yas5xx)
>  	dev_dbg(yas5xx->dev, "dck = %d\n", c->dck);
>  }
>  
> -static int yas5xx_set_offsets(struct yas5xx *yas5xx, s8 ox, s8 oy1, s8 oy2)
> +static int yas530_532_set_offsets(struct yas5xx *yas5xx, s8 ox, s8 oy1, s8 oy2)
>  {
>  	int ret;
>  
> -	ret = regmap_write(yas5xx->map, YAS5XX_OFFSET_X, ox);
> +	ret = regmap_write(yas5xx->map, YAS530_532_OFFSET_X, ox);
>  	if (ret)
>  		return ret;
> -	ret = regmap_write(yas5xx->map, YAS5XX_OFFSET_Y1, oy1);
> +	ret = regmap_write(yas5xx->map, YAS530_532_OFFSET_Y1, oy1);
>  	if (ret)
>  		return ret;
> -	return regmap_write(yas5xx->map, YAS5XX_OFFSET_Y2, oy2);
> +	return regmap_write(yas5xx->map, YAS530_532_OFFSET_Y2, oy2);
>  }
>  
> -static s8 yas5xx_adjust_offset(s8 old, int bit, u16 center, u16 measure)
> +static s8 yas530_532_adjust_offset(s8 old, int bit, u16 center, u16 measure)
>  {
>  	if (measure > center)
>  		return old + BIT(bit);
> @@ -783,7 +787,7 @@ static s8 yas5xx_adjust_offset(s8 old, int bit, u16 center, u16 measure)
>  	return old;
>  }
>  
> -static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
> +static int yas530_532_measure_offsets(struct yas5xx *yas5xx)
>  {
>  	int ret;
>  	u16 center;
> @@ -792,7 +796,7 @@ static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
>  	int i;
>  
>  	/* Actuate the init coil and measure offsets */
> -	ret = regmap_write(yas5xx->map, YAS5XX_ACTUATE_INIT_COIL, 0);
> +	ret = regmap_write(yas5xx->map, YAS530_532_ACTUATE_INIT_COIL, 0);
>  	if (ret)
>  		return ret;
>  
> @@ -826,26 +830,26 @@ static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
>  	oy2 = 0;
>  
>  	for (i = 4; i >= 0; i--) {
> -		ret = yas5xx_set_offsets(yas5xx, ox, oy1, oy2);
> +		ret = yas530_532_set_offsets(yas5xx, ox, oy1, oy2);
>  		if (ret)
>  			return ret;
>  
> -		ret = yas5xx_measure(yas5xx, &t, &x, &y1, &y2);
> +		ret = yas530_532_measure(yas5xx, &t, &x, &y1, &y2);
>  		if (ret)
>  			return ret;
>  		dev_dbg(yas5xx->dev, "measurement %d: x=%d, y1=%d, y2=%d\n",
>  			5-i, x, y1, y2);
>  
> -		ox = yas5xx_adjust_offset(ox, i, center, x);
> -		oy1 = yas5xx_adjust_offset(oy1, i, center, y1);
> -		oy2 = yas5xx_adjust_offset(oy2, i, center, y2);
> +		ox = yas530_532_adjust_offset(ox, i, center, x);
> +		oy1 = yas530_532_adjust_offset(oy1, i, center, y1);
> +		oy2 = yas530_532_adjust_offset(oy2, i, center, y2);
>  	}
>  
>  	/* Needed for calibration algorithm */
>  	yas5xx->hard_offsets[0] = ox;
>  	yas5xx->hard_offsets[1] = oy1;
>  	yas5xx->hard_offsets[2] = oy2;
> -	ret = yas5xx_set_offsets(yas5xx, ox, oy1, oy2);
> +	ret = yas530_532_set_offsets(yas5xx, ox, oy1, oy2);
>  	if (ret)
>  		return ret;
>  
> @@ -854,27 +858,27 @@ static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
>  	return 0;
>  }
>  
> -static int yas5xx_power_on(struct yas5xx *yas5xx)
> +static int yas530_532_power_on(struct yas5xx *yas5xx)
>  {
>  	unsigned int val;
>  	int ret;
>  
>  	/* Zero the test registers */
> -	ret = regmap_write(yas5xx->map, YAS5XX_TEST1, 0);
> +	ret = regmap_write(yas5xx->map, YAS530_532_TEST1, 0);
>  	if (ret)
>  		return ret;
> -	ret = regmap_write(yas5xx->map, YAS5XX_TEST2, 0);
> +	ret = regmap_write(yas5xx->map, YAS530_532_TEST2, 0);
>  	if (ret)
>  		return ret;
>  
>  	/* Set up for no interrupts, calibrated clock divider */
>  	val = FIELD_PREP(YAS5XX_CONFIG_CCK_MASK, yas5xx->calibration.dck);
> -	ret = regmap_write(yas5xx->map, YAS5XX_CONFIG, val);
> +	ret = regmap_write(yas5xx->map, YAS530_532_CONFIG, val);
>  	if (ret)
>  		return ret;
>  
>  	/* Measure interval 0 (back-to-back?)  */
> -	return regmap_write(yas5xx->map, YAS5XX_MEASURE_INTERVAL, 0);
> +	return regmap_write(yas5xx->map, YAS530_532_MEASURE_INTERVAL, 0);
>  }
>  
>  static int yas5xx_probe(struct i2c_client *i2c,
> @@ -956,11 +960,11 @@ static int yas5xx_probe(struct i2c_client *i2c,
>  		goto assert_reset;
>  	}
>  
> -	yas5xx_dump_calibration(yas5xx);
> -	ret = yas5xx_power_on(yas5xx);
> +	yas530_532_dump_calibration(yas5xx);
> +	ret = yas530_532_power_on(yas5xx);
>  	if (ret)
>  		goto assert_reset;
> -	ret = yas5xx_meaure_offsets(yas5xx);
> +	ret = yas530_532_measure_offsets(yas5xx);
>  	if (ret)
>  		goto assert_reset;
>
Jakob Hauser June 21, 2022, 12:53 a.m. UTC | #2
Hi Jonathan,

On 18.06.22 17:00, Jonathan Cameron wrote:
>
> On Sat, 18 Jun 2022 02:13:14 +0200
> Jakob Hauser <jahau@rocketmail.com> wrote:
> 
>> This is a preparation for adding YAS537 variant.
>>
>> Rename functions used only by YAS530 & YAS532 from yas5xx to yas530_532.
> 
> We've been bitten in the past by naming choices like this, so please
> use yas530 only and rely on comments or code that makes it obvious that
> it applies to the yas532 as well.

Hm, ok. It's harder to keep the overview. But I can imagine adding up
names can get out of control. I'll change it.

For functions and registers used by all variants, I'd keep yas5xx or
YAS5XX respectively. I hope that's ok.

Again I'm not sure on the "Reviewed-by:" tags. Again the patch gets
modified a lot, therefore I would remove the tags.

...

Kind regards,
Jakob
Andy Shevchenko June 21, 2022, 8:51 a.m. UTC | #3
On Tue, Jun 21, 2022 at 2:54 AM Jakob Hauser <jahau@rocketmail.com> wrote:
> On 18.06.22 17:00, Jonathan Cameron wrote:

...

> Again I'm not sure on the "Reviewed-by:" tags. Again the patch gets
> modified a lot, therefore I would remove the tags.

Yes, that's right course of actions.
Jonathan Cameron June 25, 2022, 2:16 p.m. UTC | #4
On Tue, 21 Jun 2022 02:53:58 +0200
Jakob Hauser <jahau@rocketmail.com> wrote:

> Hi Jonathan,
> 
> On 18.06.22 17:00, Jonathan Cameron wrote:
> >
> > On Sat, 18 Jun 2022 02:13:14 +0200
> > Jakob Hauser <jahau@rocketmail.com> wrote:
> >   
> >> This is a preparation for adding YAS537 variant.
> >>
> >> Rename functions used only by YAS530 & YAS532 from yas5xx to yas530_532.  
> > 
> > We've been bitten in the past by naming choices like this, so please
> > use yas530 only and rely on comments or code that makes it obvious that
> > it applies to the yas532 as well.  
> 
> Hm, ok. It's harder to keep the overview. But I can imagine adding up
> names can get out of control. I'll change it.
> 
> For functions and registers used by all variants, I'd keep yas5xx or
> YAS5XX respectively. I hope that's ok.

I reserve the right to laugh at you if the next variant to come along
fits the wild card but not the registers that have been shared until then :)

Otherwise, I'm fine with keeping the naming for those cases.

Jonathan

> 
> Again I'm not sure on the "Reviewed-by:" tags. Again the patch gets
> modified a lot, therefore I would remove the tags.
> 
> ...
> 
> Kind regards,
> Jakob
Jakob Hauser June 26, 2022, 8:39 a.m. UTC | #5
Hi Jonathan,

On 25.06.22 16:16, Jonathan Cameron wrote:
>
> On Tue, 21 Jun 2022 02:53:58 +0200
> Jakob Hauser <jahau@rocketmail.com> wrote:
> 
>> On 18.06.22 17:00, Jonathan Cameron wrote:
>>>
>>> We've been bitten in the past by naming choices like this, so please
>>> use yas530 only and rely on comments or code that makes it obvious that
>>> it applies to the yas532 as well.  
>>
>> Hm, ok. It's harder to keep the overview. But I can imagine adding up
>> names can get out of control. I'll change it.
>>
>> For functions and registers used by all variants, I'd keep yas5xx or
>> YAS5XX respectively. I hope that's ok.
> 
> I reserve the right to laugh at you if the next variant to come along
> fits the wild card but not the registers that have been shared until then :)
> 
> Otherwise, I'm fine with keeping the naming for those cases.

Thanks for your reply. Reserving that right is fine :) It could turn out
that way.

For the time being and as long as possible, keeping the generic ya5xx
naming for those cases makes it more distinguishable what's generally
applicable and what's variant-specific.

Kind regards,
Jakob
diff mbox series

Patch

diff --git a/drivers/iio/magnetometer/yamaha-yas530.c b/drivers/iio/magnetometer/yamaha-yas530.c
index c6f5f25793c4..98c8d365fab7 100644
--- a/drivers/iio/magnetometer/yamaha-yas530.c
+++ b/drivers/iio/magnetometer/yamaha-yas530.c
@@ -40,20 +40,22 @@ 
 
 #include <asm/unaligned.h>
 
-/* This register map covers YAS530 and YAS532 but differs in YAS 537 and YAS539 */
+/* Commonly used registers */
 #define YAS5XX_DEVICE_ID		0x80
-#define YAS5XX_ACTUATE_INIT_COIL	0x81
-#define YAS5XX_MEASURE			0x82
-#define YAS5XX_CONFIG			0x83
-#define YAS5XX_MEASURE_INTERVAL		0x84
-#define YAS5XX_OFFSET_X			0x85 /* [-31 .. 31] */
-#define YAS5XX_OFFSET_Y1		0x86 /* [-31 .. 31] */
-#define YAS5XX_OFFSET_Y2		0x87 /* [-31 .. 31] */
-#define YAS5XX_TEST1			0x88
-#define YAS5XX_TEST2			0x89
-#define YAS5XX_CAL			0x90
 #define YAS5XX_MEASURE_DATA		0xB0
 
+/* Registers used by YAS530 and YAS532 */
+#define YAS530_532_ACTUATE_INIT_COIL	0x81
+#define YAS530_532_MEASURE		0x82
+#define YAS530_532_CONFIG		0x83
+#define YAS530_532_MEASURE_INTERVAL	0x84
+#define YAS530_532_OFFSET_X		0x85 /* [-31 .. 31] */
+#define YAS530_532_OFFSET_Y1		0x86 /* [-31 .. 31] */
+#define YAS530_532_OFFSET_Y2		0x87 /* [-31 .. 31] */
+#define YAS530_532_TEST1		0x88
+#define YAS530_532_TEST2		0x89
+#define YAS530_532_CAL			0x90
+
 /* Bits in the YAS5xx config register */
 #define YAS5XX_CONFIG_INTON		BIT(0) /* Interrupt on? */
 #define YAS5XX_CONFIG_INTHACT		BIT(1) /* Interrupt active high? */
@@ -182,7 +184,7 @@  static u16 yas532_extract_axis(u8 *data)
 }
 
 /**
  * yas5xx_measure() - Make a measure from the hardware
  * @yas5xx: The device state
  * @t: the raw temperature measurement
  * @x: the raw x axis measurement
@@ -190,7 +192,8 @@  static u16 yas532_extract_axis(u8 *data)
  * @y2: the y2 axis measurement
  * @return: 0 on success or error code
  */
-static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y2)
+static int yas530_532_measure(struct yas5xx *yas5xx, u16 *t,
+			      u16 *x, u16 *y1, u16 *y2)
 {
 	unsigned int busy;
 	u8 data[8];
@@ -198,7 +201,7 @@  static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y
 	u16 val;
 
 	mutex_lock(&yas5xx->lock);
-	ret = regmap_write(yas5xx->map, YAS5XX_MEASURE, YAS5XX_MEASURE_START);
+	ret = regmap_write(yas5xx->map, YAS530_532_MEASURE, YAS5XX_MEASURE_START);
 	if (ret < 0)
 		goto out_unlock;
 
@@ -264,7 +267,7 @@  static int yas5xx_measure(struct yas5xx *yas5xx, u16 *t, u16 *x, u16 *y1, u16 *y
 	return ret;
 }
 
-static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
+static s32 yas530_532_linearize(struct yas5xx *yas5xx, u16 val, int axis)
 {
 	struct yas5xx_calibration *c = &yas5xx->calibration;
 	static const s32 yas532ac_coef[] = {
@@ -306,7 +309,7 @@  static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
 }
 
 /**
  * yas5xx_get_measure() - Measure a sample of all axis and process
  * @yas5xx: The device state
  * @to: Temperature out
  * @xo: X axis out
@@ -314,7 +317,8 @@  static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
  * @zo: Z axis out
  * @return: 0 on success or error code
  */
-static int yas5xx_get_measure(struct yas5xx *yas5xx, s32 *to, s32 *xo, s32 *yo, s32 *zo)
+static int yas530_532_get_measure(struct yas5xx *yas5xx, s32 *to,
+				  s32 *xo, s32 *yo, s32 *zo)
 {
 	struct yas5xx_calibration *c = &yas5xx->calibration;
 	u16 t_ref, t, x, y1, y2;
@@ -323,14 +327,14 @@  static int yas5xx_get_measure(struct yas5xx *yas5xx, s32 *to, s32 *xo, s32 *yo,
 	int ret;
 
 	/* We first get raw data that needs to be translated to [x,y,z] */
-	ret = yas5xx_measure(yas5xx, &t, &x, &y1, &y2);
+	ret = yas530_532_measure(yas5xx, &t, &x, &y1, &y2);
 	if (ret)
 		return ret;
 
 	/* Do some linearization if available */
-	sx = yas5xx_linearize(yas5xx, x, 0);
-	sy1 = yas5xx_linearize(yas5xx, y1, 1);
-	sy2 = yas5xx_linearize(yas5xx, y2, 2);
+	sx = yas530_532_linearize(yas5xx, x, 0);
+	sy1 = yas530_532_linearize(yas5xx, y1, 1);
+	sy2 = yas530_532_linearize(yas5xx, y2, 2);
 
 	/* Set the temperature reference value (unit: counts) */
 	switch (yas5xx->devid) {
@@ -602,11 +606,11 @@  static const struct regmap_config yas5xx_regmap_config = {
 };
 
 /**
  * yas53x_extract_calibration() - extracts the a2-a9 and k calibration
  * @data: the bitfield to use
  * @c: the calibration to populate
  */
-static void yas53x_extract_calibration(u8 *data, struct yas5xx_calibration *c)
+static void yas530_532_extract_calibration(u8 *data, struct yas5xx_calibration *c)
 {
 	u64 val = get_unaligned_be64(data);
 
@@ -644,12 +648,12 @@  static int yas530_get_calibration_data(struct yas5xx *yas5xx)
 	int ret;
 
 	/* Dummy read, first read is ALWAYS wrong */
-	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
+	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
 	if (ret)
 		return ret;
 
 	/* Actual calibration readout */
-	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
+	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
 	if (ret)
 		return ret;
 	dev_dbg(yas5xx->dev, "calibration data: %*ph\n", 14, data);
@@ -661,7 +665,7 @@  static int yas530_get_calibration_data(struct yas5xx *yas5xx)
 	c->Cx = data[0] * 6 - 768;
 	c->Cy1 = data[1] * 6 - 768;
 	c->Cy2 = data[2] * 6 - 768;
-	yas53x_extract_calibration(&data[3], c);
+	yas530_532_extract_calibration(&data[3], c);
 
 	/*
 	 * Extract linearization:
@@ -692,11 +696,11 @@  static int yas532_get_calibration_data(struct yas5xx *yas5xx)
 	int ret;
 
 	/* Dummy read, first read is ALWAYS wrong */
-	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
+	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
 	if (ret)
 		return ret;
 	/* Actual calibration readout */
-	ret = regmap_bulk_read(yas5xx->map, YAS5XX_CAL, data, sizeof(data));
+	ret = regmap_bulk_read(yas5xx->map, YAS530_532_CAL, data, sizeof(data));
 	if (ret)
 		return ret;
 	dev_dbg(yas5xx->dev, "calibration data: %*ph\n", 14, data);
@@ -715,7 +719,7 @@  static int yas532_get_calibration_data(struct yas5xx *yas5xx)
 	c->Cx = data[0] * 10 - 1280;
 	c->Cy1 = data[1] * 10 - 1280;
 	c->Cy2 = data[2] * 10 - 1280;
-	yas53x_extract_calibration(&data[3], c);
+	yas530_532_extract_calibration(&data[3], c);
 	/*
 	 * Extract linearization:
 	 * Linearization layout in the 32 bits at byte 10:
@@ -738,7 +742,7 @@  static int yas532_get_calibration_data(struct yas5xx *yas5xx)
 	return 0;
 }
 
-static void yas5xx_dump_calibration(struct yas5xx *yas5xx)
+static void yas530_532_dump_calibration(struct yas5xx *yas5xx)
 {
 	struct yas5xx_calibration *c = &yas5xx->calibration;
 
@@ -761,20 +765,20 @@  static void yas5xx_dump_calibration(struct yas5xx *yas5xx)
 	dev_dbg(yas5xx->dev, "dck = %d\n", c->dck);
 }
 
-static int yas5xx_set_offsets(struct yas5xx *yas5xx, s8 ox, s8 oy1, s8 oy2)
+static int yas530_532_set_offsets(struct yas5xx *yas5xx, s8 ox, s8 oy1, s8 oy2)
 {
 	int ret;
 
-	ret = regmap_write(yas5xx->map, YAS5XX_OFFSET_X, ox);
+	ret = regmap_write(yas5xx->map, YAS530_532_OFFSET_X, ox);
 	if (ret)
 		return ret;
-	ret = regmap_write(yas5xx->map, YAS5XX_OFFSET_Y1, oy1);
+	ret = regmap_write(yas5xx->map, YAS530_532_OFFSET_Y1, oy1);
 	if (ret)
 		return ret;
-	return regmap_write(yas5xx->map, YAS5XX_OFFSET_Y2, oy2);
+	return regmap_write(yas5xx->map, YAS530_532_OFFSET_Y2, oy2);
 }
 
-static s8 yas5xx_adjust_offset(s8 old, int bit, u16 center, u16 measure)
+static s8 yas530_532_adjust_offset(s8 old, int bit, u16 center, u16 measure)
 {
 	if (measure > center)
 		return old + BIT(bit);
@@ -783,7 +787,7 @@  static s8 yas5xx_adjust_offset(s8 old, int bit, u16 center, u16 measure)
 	return old;
 }
 
-static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
+static int yas530_532_measure_offsets(struct yas5xx *yas5xx)
 {
 	int ret;
 	u16 center;
@@ -792,7 +796,7 @@  static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
 	int i;
 
 	/* Actuate the init coil and measure offsets */
-	ret = regmap_write(yas5xx->map, YAS5XX_ACTUATE_INIT_COIL, 0);
+	ret = regmap_write(yas5xx->map, YAS530_532_ACTUATE_INIT_COIL, 0);
 	if (ret)
 		return ret;
 
@@ -826,26 +830,26 @@  static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
 	oy2 = 0;
 
 	for (i = 4; i >= 0; i--) {
-		ret = yas5xx_set_offsets(yas5xx, ox, oy1, oy2);
+		ret = yas530_532_set_offsets(yas5xx, ox, oy1, oy2);
 		if (ret)
 			return ret;
 
-		ret = yas5xx_measure(yas5xx, &t, &x, &y1, &y2);
+		ret = yas530_532_measure(yas5xx, &t, &x, &y1, &y2);
 		if (ret)
 			return ret;
 		dev_dbg(yas5xx->dev, "measurement %d: x=%d, y1=%d, y2=%d\n",
 			5-i, x, y1, y2);
 
-		ox = yas5xx_adjust_offset(ox, i, center, x);
-		oy1 = yas5xx_adjust_offset(oy1, i, center, y1);
-		oy2 = yas5xx_adjust_offset(oy2, i, center, y2);
+		ox = yas530_532_adjust_offset(ox, i, center, x);
+		oy1 = yas530_532_adjust_offset(oy1, i, center, y1);
+		oy2 = yas530_532_adjust_offset(oy2, i, center, y2);
 	}
 
 	/* Needed for calibration algorithm */
 	yas5xx->hard_offsets[0] = ox;
 	yas5xx->hard_offsets[1] = oy1;
 	yas5xx->hard_offsets[2] = oy2;
-	ret = yas5xx_set_offsets(yas5xx, ox, oy1, oy2);
+	ret = yas530_532_set_offsets(yas5xx, ox, oy1, oy2);
 	if (ret)
 		return ret;
 
@@ -854,27 +858,27 @@  static int yas5xx_meaure_offsets(struct yas5xx *yas5xx)
 	return 0;
 }
 
-static int yas5xx_power_on(struct yas5xx *yas5xx)
+static int yas530_532_power_on(struct yas5xx *yas5xx)
 {
 	unsigned int val;
 	int ret;
 
 	/* Zero the test registers */
-	ret = regmap_write(yas5xx->map, YAS5XX_TEST1, 0);
+	ret = regmap_write(yas5xx->map, YAS530_532_TEST1, 0);
 	if (ret)
 		return ret;
-	ret = regmap_write(yas5xx->map, YAS5XX_TEST2, 0);
+	ret = regmap_write(yas5xx->map, YAS530_532_TEST2, 0);
 	if (ret)
 		return ret;
 
 	/* Set up for no interrupts, calibrated clock divider */
 	val = FIELD_PREP(YAS5XX_CONFIG_CCK_MASK, yas5xx->calibration.dck);
-	ret = regmap_write(yas5xx->map, YAS5XX_CONFIG, val);
+	ret = regmap_write(yas5xx->map, YAS530_532_CONFIG, val);
 	if (ret)
 		return ret;
 
 	/* Measure interval 0 (back-to-back?)  */
-	return regmap_write(yas5xx->map, YAS5XX_MEASURE_INTERVAL, 0);
+	return regmap_write(yas5xx->map, YAS530_532_MEASURE_INTERVAL, 0);
 }
 
 static int yas5xx_probe(struct i2c_client *i2c,
@@ -956,11 +960,11 @@  static int yas5xx_probe(struct i2c_client *i2c,
 		goto assert_reset;
 	}
 
-	yas5xx_dump_calibration(yas5xx);
-	ret = yas5xx_power_on(yas5xx);
+	yas530_532_dump_calibration(yas5xx);
+	ret = yas530_532_power_on(yas5xx);
 	if (ret)
 		goto assert_reset;
-	ret = yas5xx_meaure_offsets(yas5xx);
+	ret = yas530_532_measure_offsets(yas5xx);
 	if (ret)
 		goto assert_reset;
@@ -182,7 +184,7 @@  static u16 yas532_extract_axis(u8 *data)
 
 /**
- * yas5xx_measure() - Make a measure from the hardware
+ * yas530_532_measure() - Make a measure from the hardware
  * @yas5xx: The device state
  * @t: the raw temperature measurement
@@ -306,7 +309,7 @@  static s32 yas5xx_linearize(struct yas5xx *yas5xx, u16 val, int axis)
 
 /**
- * yas5xx_get_measure() - Measure a sample of all axis and process
+ * yas530_532_get_measure() - Measure a sample of all axis and process
  * @yas5xx: The device state
  * @to: Temperature out
@@ -602,11 +606,11 @@  static const struct regmap_config yas5xx_regmap_config = {
 
 /**
- * yas53x_extract_calibration() - extracts the a2-a9 and k calibration
+ * yas530_532_extract_calibration() - extracts the a2-a9 and k calibration
  * @data: the bitfield to use
  * @c: the calibration to populate